==> 0.2.11.tar.gz: lib/pages/likes_and_dislikes.dart <==
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:timeago/timeago.dart' as timeago;

class LikesAndDislikes extends StatefulWidget {
  const LikesAndDislikes(
      {Key key,
      @required this.likesList,
      @required this.dislikesList,
      @required this.postTitle,
      @required this.loc})
      : super(key: key);

  final List<ReportModel> likesList;
  final List<ReportModel> dislikesList;
  final String postTitle;
  final loc;
  @override
  _LikesAndDislikesState createState() => _LikesAndDislikesState();
}

class _LikesAndDislikesState extends State<LikesAndDislikes> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
          designSize: Size(width, height),
          allowFontScaling: false,
          builder: () => DefaultTabController(
                length: 2,
                child: Scaffold(
                  appBar: PreferredSize(
                      preferredSize: Size.fromHeight(
                        ScreenUtil().setWidth(115),
                      ),
                      child: AppBar(
                        backgroundColor: Color(0xFF083356),
                        leading: Padding(
                          padding: EdgeInsets.only(
                            top: ScreenUtil().setWidth(9),
                          ),
                          child: IconButton(
                            onPressed: () {
                              Navigator.pop(context);
                            },
                            icon: Icon(Icons.arrow_back, color: Colors.white),
                          ),
                        ),
                        title: Expanded(
                          child: Container(
                            child: Text(
                              this.widget.postTitle,
                              style: TextStyle(
                                color: Colors.white,
                              ),
                            ),
                          ),
                        ),
                        bottom: PreferredSize(
                          preferredSize: tabBar.preferredSize,
                          child: Container(
                            height: ScreenUtil().setWidth(56),
                            child: ColoredBox(
                              color: Colors.white,
                              child: tabBar,
                            ),
                          ),
                        ),
                      )),
                  body: Directionality(
                    textDirection: TextDirection.ltr,
                    child: PreferredSize(
                      preferredSize: Size.fromHeight(70.0),
                      child: TabBarView(
                        children: [
                          _buildList(this.widget.likesList, "Likes"),
                          _buildList(this.widget.dislikesList, "Dislikes"),
                        ],
                      ),
                    ),
                  ),
                ),
              )),
    );
  }

  TabBar get tabBar => TabBar(
        labelColor: Color(0xFF083356),
        unselectedLabelColor: Color(0xFF083356),
        indicatorColor: Color(0xFFE083356),
        indicatorWeight: 5,
        labelStyle: TextStyle(
            fontWeight: FontWeight.bold, fontSize: ScreenUtil().setWidth(15)),
        unselectedLabelStyle: TextStyle(
            fontWeight: FontWeight.normal, fontSize: ScreenUtil().setWidth(15)),
        tabs: [
          Tab(
              child: Text(
            this.widget.loc.translate("Likes") +
                "(" +
                this.widget.likesList.length.toString() +
                ")",
          )),
          Tab(
            child: Text(
              this.widget.loc.translate("Dislikes") +
                  "(" +
                  this.widget.dislikesList.length.toString() +
                  ")",
            ),
          ),
        ],
      );

  _buildList(listToShow, type) {
    return listToShow.length > 0
        ? ListView.builder(
            padding: EdgeInsets.all(ScreenUtil().setWidth(8)),
            itemCount: listToShow.length,
            itemBuilder: (BuildContext context, int index) {
              UserModel userData = listToShow[index].user;
              final date = DateTime.now();
              final difference =
                  date.difference(listToShow[index].createdAt).inMinutes;
              final fifteenAgo = new DateTime.now()
                  .subtract(new Duration(minutes: difference));
              return Container(
                  height: ScreenUtil().setHeight(110),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Container(
                          margin: EdgeInsets.only(
                            top: ScreenUtil().setWidth(15),
                          ),
                          height: ScreenUtil().setWidth(200),
                          width: ScreenUtil().setWidth(60),
                          child: Stack(children: <Widget>[
                            userData.profileImg == null ||
                                    userData.profileImg == "" ||
                                    userData.profileImg == "null"
                                ? DefaultProfileImg(
                                    firstName: userData.firstName,
                                    lastName: userData.lastName,
                                  )
                                // ClipOval(
                                //     child: Material(
                                //       color: Color(0xffE8ECEF),
                                //       child: SizedBox(
                                //         width: ScreenUtil().setWidth(38),
                                //         height: ScreenUtil().setWidth(39),
                                //         child: Center(
                                //           child: Text(
                                //             userData.firstName.substring(0, 1) +
                                //                 userData.lastName
                                //                     .substring(0, 1),
                                //             style: TextStyle(
                                //               color: Color(0xFF083356),
                                //               fontSize: ScreenUtil().setSp(15),
                                //             ),
                                //           ),
                                //         ),
                                //       ),
                                //     ),
                                // )
                                : ClipOval(
                                    child: Image.network(
                                      userData.profileImg,
                                      width: ScreenUtil().setWidth(38),
                                      height: ScreenUtil().setWidth(39),
                                      fit: BoxFit.cover,
                                    ),
                                  ),
                            Row(
                              children: [
                                Expanded(child: Container()),
                                Expanded(
                                  child: Container(
                                    width: ScreenUtil().setWidth(25),
                                    height: ScreenUtil().setHeight(25),
                                    alignment: Alignment.bottomRight,
                                    margin: EdgeInsets.only(
                                        bottom: ScreenUtil().setWidth(30)),
                                    //     left: ScreenUtil().setWidth(15),
                                    // top: ScreenUtil().setWidth(15)),
                                    child: ClipOval(
                                        child: Container(
                                      width: ScreenUtil().setWidth(16),
                                      height: ScreenUtil().setWidth(19),
                                      color: type == "Likes"
                                          ? Colors.green
                                          : Colors.red,
                                      child: SizedBox(
                                          width: 12,
                                          height: 12,
                                          child: Icon(
                                            type == "Likes"
                                                ? Icons.thumb_up_off_alt
                                                : Icons.thumb_down_off_alt,
                                            size: 13,
                                            color:
                                                Colors.black.withOpacity(0.5),
                                          )),
                                    )),
                                  ),
                                ),
                                Expanded(child: Container()),
                              ],
                            ),
                          ])),
                      Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Row(children: [
                              Container(
                                width: ScreenUtil().setWidth(220),
                                margin: EdgeInsets.only(
                                    top: ScreenUtil().setWidth(15)),
                                child: Text(
                                    userData.lastName != null &&
                                            userData.lastName != "null"
                                        ? userData.firstName.toString() +
                                            " " +
                                            userData.lastName.toString()
                                        : userData.firstName.toString(),
                                    style:
                                        TextStyle(fontWeight: FontWeight.bold)),
                              ),
                              Container(
                                margin: EdgeInsets.only(
                                    top: ScreenUtil().setWidth(15)),
                                child: Text(
                                  timeago.format(fifteenAgo,
                                      locale: 'en_short'),
                                  style: TextStyle(
                                    color: Color(0xFF98A9BC),
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                              )
                            ]),
                            Text(
                              userData.about != null && userData.about != "null"
                                  ? userData.about.split('\n')[0]
                                  : "",
                              style: TextStyle(
                                color: Color(0xFF98A9BC),
                                height: 2,
                              ),
                            ),
                          ]),
                    ],
                  ));
            })
        : Padding(
            padding: const EdgeInsets.all(50),
            child: Text(
              this.widget.loc.translate("No ") +
                  this.widget.loc.translate(type) +
                  this.widget.loc.translate(" yet..."),
              textAlign: TextAlign.center,
              style: TextStyle(
                  fontSize: ScreenUtil().setWidth(20),
                  color: Color(0xFF98A9BC)),
            ),
          );
  }
}

==> 0.2.18.tar.gz: lib/pages/likes_and_dislikes.dart <==
import 'package:feed_plugin/widgets/default_profile_img.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:feed_plugin/models/report_model.dart';
import 'package:feed_plugin/models/user_model.dart';
import 'package:flutter_screenutil/screenutil_init.dart';
import 'package:timeago/timeago.dart' as timeago;

class LikesAndDislikes extends StatefulWidget {
  const LikesAndDislikes(
      {Key key,
      @required this.likesList,
      @required this.dislikesList,
      @required this.postTitle,
      @required this.loc})
      : super(key: key);

  final List<ReportModel> likesList;
  final List<ReportModel> dislikesList;
  final String postTitle;
  final loc;
  @override
  _LikesAndDislikesState createState() => _LikesAndDislikesState();
}

class _LikesAndDislikesState extends State<LikesAndDislikes> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
      textDirection: TextDirection.ltr,
      child: ScreenUtilInit(
          designSize: Size(width, height),
          allowFontScaling: false,
          builder: () => DefaultTabController(
                length: 2,
                child: Scaffold(
                  appBar: PreferredSize(
                      preferredSize: Size.fromHeight(
                        ScreenUtil().setWidth(115),
                      ),
                      child: AppBar(
                        backgroundColor: Color(0xFF083356),
                        leading: Padding(
                          padding: EdgeInsets.only(
                            top: ScreenUtil().setWidth(9),
                          ),
                          child: IconButton(
                            onPressed: () {
                              Navigator.pop(context);
                            },
                            icon: Icon(Icons.arrow_back, color: Colors.white),
                          ),
                        ),
                        title: Text(
                          this.widget.postTitle,
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                        bottom: PreferredSize(
                          preferredSize: tabBar.preferredSize,
                          child: Container(
                            height: ScreenUtil().setWidth(56),
                            child: ColoredBox(
                              color: Colors.white,
                              child: tabBar,
                            ),
                          ),
                        ),
                      )),
                  body: Directionality(
                    textDirection: TextDirection.ltr,
                    child: PreferredSize(
                      preferredSize: Size.fromHeight(70.0),
                      child: TabBarView(
                        children: [
                          _buildList(this.widget.likesList, "Likes"),
                          _buildList(this.widget.dislikesList, "Dislikes"),
                        ],
                      ),
                    ),
                  ),
                ),
              )),
    );
  }

  TabBar get tabBar => TabBar(
        labelColor: Color(0xFF083356),
        unselectedLabelColor: Color(0xFF083356),
        indicatorColor: Color(0xFFE083356),
        indicatorWeight: 5,
        labelStyle: TextStyle(
            fontWeight: FontWeight.bold, fontSize: ScreenUtil().setWidth(15)),
        unselectedLabelStyle: TextStyle(
            fontWeight: FontWeight.normal, fontSize: ScreenUtil().setWidth(15)),
        tabs: [
          Tab(
              child: Text(
            this.widget.loc.translate("Likes") +
                "(" +
                this.widget.likesList.length.toString() +
                ")",
          )),
          Tab(
            child: Text(
              this.widget.loc.translate("Dislikes") +
                  "(" +
                  this.widget.dislikesList.length.toString() +
                  ")",
            ),
          ),
        ],
      );

  _buildList(listToShow, type) {
    return listToShow.length > 0
        ? ListView.builder(
            padding: EdgeInsets.all(ScreenUtil().setWidth(8)),
            itemCount: listToShow.length,
            itemBuilder: (BuildContext context, int index) {
              UserModel userData = listToShow[index].user;
              final date = DateTime.now();
              final difference =
                  date.difference(listToShow[index].createdAt).inMinutes;
              final fifteenAgo = new DateTime.now()
                  .subtract(new Duration(minutes: difference));
              return Container(
                  height: ScreenUtil().setHeight(110),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      Container(
                          margin: EdgeInsets.only(
                            top: ScreenUtil().setWidth(15),
                          ),
                          height: ScreenUtil().setWidth(200),
                          width: ScreenUtil().setWidth(60),
                          child: Stack(children: <Widget>[
                            userData.profileImg == null ||
                                    userData.profileImg == "" ||
                                    userData.profileImg == "null"
                                ? DefaultProfileImg(
                                    firstName: userData.firstName,
                                    lastName: userData.lastName,
                                  )
                                : ClipOval(
                                    child: Image.network(
                                      userData.profileImg,
                                      width: ScreenUtil().setWidth(38),
                                      height: ScreenUtil().setWidth(39),
                                      fit: BoxFit.cover,
                                    ),
                                  ),
                            Container(
                              width: ScreenUtil().setWidth(38),
                              height: ScreenUtil().setHeight(40),
                              alignment: Alignment.bottomRight,
                              margin: EdgeInsets.only(
                                  bottom: ScreenUtil().setWidth(30)),
                              child: ClipOval(
                                  child: Container(
                                width: ScreenUtil().setWidth(16),
                                height: ScreenUtil().setWidth(19),
                                color:
                                    type == "Likes" ? Colors.green : Colors.red,
                                child: SizedBox(
                                    width: 12,
                                    height: 12,
                                    child: Icon(
                                      type == "Likes"
                                          ? Icons.thumb_up_off_alt
                                          : Icons.thumb_down_off_alt,
                                      size: 13,
                                      color: Colors.black.withOpacity(0.5),
                                    )),
                              )),
                            ),
                          ])),
                      Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Row(children: [
                              Container(
                                width: ScreenUtil().setWidth(220),
                                margin: EdgeInsets.only(
                                    top: ScreenUtil().setWidth(15)),
                                child: Text(
                                    userData.lastName != null &&
                                            userData.lastName != "null"
                                        ? userData.firstName.toString() +
                                            " " +
                                            userData.lastName.toString()
                                        : userData.firstName.toString(),
                                    style:
                                        TextStyle(fontWeight: FontWeight.bold)),
                              ),
                              Container(
                                margin: EdgeInsets.only(
                                    top: ScreenUtil().setWidth(15)),
                                child: Text(
                                  timeago.format(fifteenAgo,
                                      locale: 'en_short'),
                                  style: TextStyle(
                                    color: Color(0xFF98A9BC),
                                    fontWeight: FontWeight.bold,
                                  ),
                                ),
                              )
                            ]),
                            Text(
                              userData.about != null && userData.about != "null"
                                  ? userData.about.split('\n')[0]
                                  : "",
                              style: TextStyle(
                                color: Color(0xFF98A9BC),
                                height: 2,
                              ),
                            ),
                          ]),
                    ],
                  ));
            })
        : Padding(
            padding: const EdgeInsets.all(50),
            child: Text(
              this.widget.loc.translate("No ") +
                  this.widget.loc.translate(type) +
                  this.widget.loc.translate(" yet..."),
              textAlign: TextAlign.center,
              style: TextStyle(
                  fontSize: ScreenUtil().setWidth(20),
                  color: Color(0xFF98A9BC)),
            ),
          );
  }
}
